==> haskell-conduit-1.3.1.1-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.3.1.1
id: conduit-1.3.1.1-JSdi7R8L6wUIGZiBi8qKpO
key: conduit-1.3.1.1-JSdi7R8L6wUIGZiBi8qKpO
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.
    .
    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).
    .
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
category: Data, Conduit
abi: 5a2bb6a84369d9dcceea6d08be924358
exposed: True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit Data.Conduit.Combinators.Unqualified
                Data.Streaming.FileRead Data.Streaming.Filesystem
import-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-1.3.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-1.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/conduit-1.3.1.1
hs-libraries: HSconduit-1.3.1.1-JSdi7R8L6wUIGZiBi8qKpO
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    exceptions-0.10.2-Gj8cIuYcXhQEAym4RMvM4g filepath-1.4.2.1
    mono-traversable-1.0.11.0-HsRoB5Ve4Dy9TOyE4PSKGV mtl-2.2.2
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    resourcet-1.2.2-BD7KiCA7p3Q4m6RD0qps5k text-1.2.3.1
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-1.3.1.1-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.3.1.1
id: conduit-1.3.1.1-BJf0jROjhGpHw40KA5fH20
key: conduit-1.3.1.1-BJf0jROjhGpHw40KA5fH20
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.
    .
    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).
    .
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
category: Data, Conduit
abi: 6f29e05d2939d7e5ff18dc48b3139ba0
exposed: True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit Data.Conduit.Combinators.Unqualified
                Data.Streaming.FileRead Data.Streaming.Filesystem
import-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-1.3.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-1.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/conduit-1.3.1.1
hs-libraries: HSconduit-1.3.1.1-BJf0jROjhGpHw40KA5fH20
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    exceptions-0.10.2-Gj8cIuYcXhQEAym4RMvM4g filepath-1.4.2.1
    mono-traversable-1.0.11.0-HsRoB5Ve4Dy9TOyE4PSKGV mtl-2.2.2
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    resourcet-1.2.2-BD7KiCA7p3Q4m6RD0qps5k text-1.2.3.1
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
